@@ -1,21 +1,9 @@
-glubort <- function(..., .sep = "", .envir = caller_env(), .call = .envir) {
-  abort(glue(..., .sep = .sep, .envir = .envir), call = .call)
-}
-
-glue_quote_collapse <- function(x) {
-  glue::glue_collapse(glue::single_quote(x), sep = ", ")
-}
-
 simplify_terms <- function(x) {
 
   # This is like stats:::terms.default
   # but doesn't look at x$terms.
 
-  is_terms <- inherits(x, "terms")
-
-  if (!is_terms) {
-    abort("`x` must be a terms object")
-  }
+  check_terms(x)
 
   # It removes the environment
   # (which could be large)
@@ -34,7 +22,9 @@ simplify_terms <- function(x) {
 # - RHS `.` should be expanded ahead of time by `expand_formula_dot_notation()`
 # - Can't use `get_all_vars()` because it chokes on formulas with variables with
 #   spaces like ~ `x y`
-get_all_predictors <- function(formula, data) {
+get_all_predictors <- function(formula, data, ..., call = caller_env()) {
+  check_dots_empty0(...)
+
   predictor_formula <- new_formula(
     lhs = NULL,
     rhs = f_rhs(formula),
@@ -45,8 +35,11 @@ get_all_predictors <- function(formula, data) {
 
   extra_predictors <- setdiff(predictors, names(data))
   if (length(extra_predictors) > 0) {
-    extra_predictors <- glue_quote_collapse(extra_predictors)
-    glubort("The following predictors were not found in `data`: {extra_predictors}.")
+    cli::cli_abort(
+      "The following predictor{?s} {?was/were} not found in {.arg data}:
+      {.val {extra_predictors}}.",
+      call = call
+    )
   }
 
   predictors
@@ -54,7 +47,9 @@ get_all_predictors <- function(formula, data) {
 
 # LHS `.` are NOT expanded by `expand_formula_dot_notation()`, and should be
 # considered errors
-get_all_outcomes <- function(formula, data) {
+get_all_outcomes <- function(formula, data, ..., call = caller_env()) {
+  check_dots_empty0(...)
+
   outcome_formula <- new_formula(
     lhs = f_lhs(formula),
     rhs = 1,
@@ -64,13 +59,19 @@ get_all_outcomes <- function(formula, data) {
   outcomes <- all.vars(outcome_formula)
 
   if ("." %in% outcomes) {
-    abort("The left hand side of the formula cannot contain `.`")
+    cli::cli_abort(
+      "The left-hand side of the formula cannot contain {.code .}.",
+      call = call
+    )
   }
 
   extra_outcomes <- setdiff(outcomes, names(data))
   if (length(extra_outcomes) > 0) {
-    extra_outcomes <- glue_quote_collapse(extra_outcomes)
-    glubort("The following outcomes were not found in `data`: {extra_outcomes}.")
+    cli::cli_abort(
+      "The following outcome{?s} {?was/were} not found in {.arg data}:
+      {.val {extra_outcomes}}.",
+      call = call
+    )
   }
 
   outcomes
@@ -150,10 +151,6 @@ has_unique_column_names <- function(x) {
   !anyDuplicated(nms)
 }
 
-class1 <- function(x) {
-  class(x)[1]
-}
-
 # ------------------------------------------------------------------------------
 
 check_data_frame_or_matrix <- function(x,
