@@ -39,7 +39,7 @@ validate_outcomes_are_univariate <- function(outcomes) {
   check <- check_outcomes_are_univariate(outcomes)
 
   if (!check$ok) {
-    glubort(
+    cli::cli_abort(
       "The outcome must be univariate, but {check$n_cols} columns were found."
     )
   }
@@ -81,6 +81,8 @@ check_outcomes_are_univariate <- function(outcomes) {
 #' and the values are the classes of the matching column.
 #'
 #' @param outcomes An object to check.
+#' 
+#' @inheritParams validate_column_names
 #'
 #' @return
 #'
@@ -111,25 +113,32 @@ validate_outcomes_are_numeric <- function(outcomes) {
   check <- check_outcomes_are_numeric(outcomes)
 
   if (!check$ok) {
-    bad_cols <- glue::single_quote(names(check$bad_classes))
-    bad_printable_classes <- map(check$bad_classes, glue_quote_collapse)
-    bad_msg <- glue::glue("{bad_cols}: {bad_printable_classes}")
-    bad_msg <- glue::glue_collapse(bad_msg, sep = "\n")
+    bad_msg <- style_bad_classes(check$bad_classes)
 
-    glubort(
-      "All outcomes must be numeric, but the following are not:",
-      "\n",
-      "{bad_msg}"
+    cli::cli_abort(
+      c(
+        "All outcomes must be numeric.",
+        "i" = "{cli::qty(length(check$bad_classes))}The following {?is/are} not:",
+        bad_msg
+      )
     )
   }
 
   invisible(outcomes)
 }
 
+style_bad_classes <- function(bad_classes){
+  bad_col <- map(names(bad_classes), ~ cli::format_inline("{.val {.x}}"))
+  bad_class <- map(bad_classes, ~ cli::format_inline("{.cls {.x}}"))
+
+  glue::glue("{bad_col}: {bad_class}")
+}
+
 #' @rdname validate_outcomes_are_numeric
 #' @export
-check_outcomes_are_numeric <- function(outcomes) {
-  check_data_frame_or_matrix(outcomes)
+check_outcomes_are_numeric <- function(outcomes, ..., call = caller_env()) {
+  check_dots_empty0(...)
+  check_data_frame_or_matrix(outcomes, call = call)
   outcomes <- coerce_to_tibble(outcomes)
 
   where_numeric <- map_lgl(outcomes, is.numeric)
@@ -163,6 +172,8 @@ check_outcomes_are_numeric <- function(outcomes) {
 #' and the values are the classes of the matching column.
 #'
 #' @param outcomes An object to check.
+#' 
+#' @inheritParams validate_column_names
 #'
 #' @return
 #'
@@ -190,15 +201,14 @@ validate_outcomes_are_factors <- function(outcomes) {
   check <- check_outcomes_are_factors(outcomes)
 
   if (!check$ok) {
-    bad_cols <- glue::single_quote(names(check$bad_classes))
-    bad_printable_classes <- map(check$bad_classes, glue_quote_collapse)
-    bad_msg <- glue::glue("{bad_cols}: {bad_printable_classes}")
-    bad_msg <- glue::glue_collapse(bad_msg, sep = "\n")
+    bad_msg <- style_bad_classes(check$bad_classes)
 
-    glubort(
-      "All outcomes must be factors, but the following are not:",
-      "\n",
-      "{bad_msg}"
+    cli::cli_abort(
+      c(
+        "All outcomes must be factors.",
+        "i" = "{cli::qty(length(check$bad_classes))}The following {?is/are} not:",
+        bad_msg
+      )
     )
   }
 
@@ -207,8 +217,9 @@ validate_outcomes_are_factors <- function(outcomes) {
 
 #' @rdname validate_outcomes_are_factors
 #' @export
-check_outcomes_are_factors <- function(outcomes) {
-  check_data_frame_or_matrix(outcomes)
+check_outcomes_are_factors <- function(outcomes, ..., call = caller_env()) {
+  check_dots_empty0(...)
+  check_data_frame_or_matrix(outcomes, call = call)
   outcomes <- coerce_to_tibble(outcomes)
 
   where_factor <- map_lgl(outcomes, is.factor)
@@ -216,7 +227,7 @@ check_outcomes_are_factors <- function(outcomes) {
   ok <- all(where_factor)
 
   if (!ok) {
-    bad_classes <- get_data_classes(outcomes[, !where_factor])
+    bad_classes <- get_data_classes(outcomes[, !where_factor], call = call)
   } else {
     bad_classes <- list()
   }
@@ -244,6 +255,8 @@ check_outcomes_are_factors <- function(outcomes) {
 #' with problems.
 #'
 #' @param outcomes An object to check.
+#' 
+#' @inheritParams validate_column_names
 #'
 #' @return
 #'
@@ -274,15 +287,17 @@ validate_outcomes_are_binary <- function(outcomes) {
   check <- check_outcomes_are_binary(outcomes)
 
   if (!check$ok) {
-    bad_cols <- glue::single_quote(check$bad_cols)
-    bad_msg <- glue::glue("{bad_cols}: {check$num_levels}")
-    bad_msg <- glue::glue_collapse(bad_msg, sep = "\n")
+    bad_col <- map(check$bad_cols, ~ cli::format_inline("{.val {.x}}"))
 
-    glubort(
-      "The outcome must be binary, ",
-      "but the following number of levels were found:",
-      "\n",
-      "{bad_msg}"
+    bad_msg <- glue::glue("{bad_col}: {check$num_levels}")
+
+    cli::cli_abort(
+      c(
+        "The outcome must be binary.",
+        "i" = "{cli::qty(length(bad_col))}The following number of levels
+               {?was/were} found:",
+        bad_msg
+      )
     )
   }
 
@@ -291,8 +306,9 @@ validate_outcomes_are_binary <- function(outcomes) {
 
 #' @rdname validate_outcomes_are_binary
 #' @export
-check_outcomes_are_binary <- function(outcomes) {
-  check_data_frame_or_matrix(outcomes)
+check_outcomes_are_binary <- function(outcomes, ..., call = caller_env()) {
+  check_dots_empty0(...)
+  check_data_frame_or_matrix(outcomes, call = call)
   outcomes <- coerce_to_tibble(outcomes)
 
   outcomes_levels <- map(outcomes, levels)
@@ -336,6 +352,8 @@ is_binary <- function(x) {
 #' and the values are the classes of the matching column.
 #'
 #' @param predictors An object to check.
+#' 
+#' @inheritParams validate_column_names
 #'
 #' @return
 #'
@@ -366,15 +384,14 @@ validate_predictors_are_numeric <- function(predictors) {
   check <- check_predictors_are_numeric(predictors)
 
   if (!check$ok) {
-    bad_cols <- glue::single_quote(names(check$bad_classes))
-    bad_printable_classes <- map(check$bad_classes, glue_quote_collapse)
-    bad_msg <- glue::glue("{bad_cols}: {bad_printable_classes}")
-    bad_msg <- glue::glue_collapse(bad_msg, sep = "\n")
+    bad_msg <- style_bad_classes(check$bad_classes)
 
-    glubort(
-      "All predictors must be numeric, but the following are not:",
-      "\n",
-      "{bad_msg}"
+    cli::cli_abort(
+      c(
+        "All predictors must be numeric.",
+        "i" = "{cli::qty(length(check$bad_classes))}The following {?is/are} not:",
+        bad_msg
+      )
     )
   }
 
@@ -383,8 +400,9 @@ validate_predictors_are_numeric <- function(predictors) {
 
 #' @rdname validate_predictors_are_numeric
 #' @export
-check_predictors_are_numeric <- function(predictors) {
-  check_data_frame_or_matrix(predictors)
+check_predictors_are_numeric <- function(predictors, ..., call = caller_env()) {
+  check_dots_empty0(...)
+  check_data_frame_or_matrix(predictors, call = call)
   predictors <- coerce_to_tibble(predictors)
 
   where_numeric <- map_lgl(predictors, is.numeric)
@@ -430,6 +448,10 @@ check_predictors_are_numeric <- function(predictors) {
 #' @param data A data frame to check.
 #'
 #' @param original_names A character vector. The original column names.
+#' 
+#' @inheritParams rlang::args_dots_empty
+#' 
+#' @param call The call used for errors and warnings.
 #'
 #' @return
 #'
@@ -486,20 +508,21 @@ check_predictors_are_numeric <- function(predictors) {
 #' forge(test, processed$blueprint, outcomes = TRUE)
 #' @family validation functions
 #' @export
-validate_column_names <- function(data, original_names) {
-  check_data_frame_or_matrix(data)
+validate_column_names <- function(data, original_names, ..., call = current_env()) {
+  check_dots_empty()
+
+  check_data_frame_or_matrix(data, call = call)
   data <- coerce_to_tibble(data)
 
   check <- check_column_names(data, original_names)
 
   if (!check$ok) {
-    validate_missing_name_isnt_.outcome(check$missing_names)
+    validate_missing_name_isnt_.outcome(check$missing_names, call = call)
 
-    missing_names <- glue_quote_collapse(check$missing_names)
-
-    message <- glue("The following required columns are missing: {missing_names}.")
-
-    abort(message)
+    cli::cli_abort(
+      "The required column{?s} {.val {check$missing_names}} {?is/are} missing.",
+      call = call
+    )
   }
 
   invisible(data)
@@ -508,9 +531,7 @@ validate_column_names <- function(data, original_names) {
 #' @rdname validate_column_names
 #' @export
 check_column_names <- function(data, original_names) {
-  if (!is.character(original_names)) {
-    glubort("`original_names` must be a character vector.")
-  }
+  check_character(original_names)
 
   new_names <- colnames(data)
 
@@ -527,19 +548,21 @@ check_column_names <- function(data, original_names) {
   new_check_result(ok = ok, missing_names = missing_names)
 }
 
-validate_missing_name_isnt_.outcome <- function(missing_names) {
+validate_missing_name_isnt_.outcome <- function(missing_names, ..., call = caller_env()) {
+  check_dots_empty0(...)
+
   not_ok <- ".outcome" %in% missing_names
 
   if (not_ok) {
-    missing_names <- glue_quote_collapse(missing_names)
-
-    glubort(
-      "The following required columns are missing: {missing_names}.
-
-      (This indicates that `mold()` was called with a vector for `y`. ",
-      "When this is the case, and the outcome columns are requested ",
-      "in `forge()`, `new_data` must include a column with the automatically ",
-      "generated name, '.outcome', containing the outcome.)"
+    cli::cli_abort(
+      c(
+        "The following required columns are missing: {.val {missing_names}}.",
+        "i" = "This indicates that {.fn mold} was called with a vector for {.arg y}.",
+        "i" = "When this is the case, and the outcome columns are requested in
+           {.fn forge}, {.arg new_data} must include a column with the
+           automatically generated name, {.code .outcome}, containing the outcome."
+      ),
+      call = call
     )
   }
 
@@ -569,6 +592,8 @@ validate_missing_name_isnt_.outcome <- function(missing_names) {
 #' [spruce_numeric()].
 #'
 #' @param new_data A data frame of new predictors and possibly outcomes.
+#' 
+#' @inheritParams validate_column_names
 #'
 #' @return
 #'
@@ -615,9 +640,9 @@ validate_prediction_size <- function(pred, new_data) {
   check <- check_prediction_size(pred, new_data)
 
   if (!check$ok) {
-    glubort(
-      "The size of `new_data` ({check$size_new_data}) must match the ",
-      "size of `pred` ({check$size_pred})."
+    cli::cli_abort(
+      "The size of {.arg new_data} ({check$size_new_data}) must match the
+      size of {.arg pred} ({check$size_pred})."
     )
   }
 
@@ -626,8 +651,9 @@ validate_prediction_size <- function(pred, new_data) {
 
 #' @rdname validate_prediction_size
 #' @export
-check_prediction_size <- function(pred, new_data) {
-  check_data_frame_or_matrix(new_data)
+check_prediction_size <- function(pred, new_data, ..., call = caller_env()) {
+  check_dots_empty0(...)
+  check_data_frame_or_matrix(new_data, call = call)
   new_data <- coerce_to_tibble(new_data)
 
   size_new_data <- vec_size(new_data)
@@ -692,11 +718,13 @@ validate_no_formula_duplication <- function(formula, original = FALSE) {
   check <- check_no_formula_duplication(formula, original)
 
   if (!check$ok) {
-    duplicates <- glue_quote_collapse(check$duplicates)
-
-    glubort(
-      "The following terms are duplicated on the left and right hand side ",
-      "of the `formula`: {duplicates}."
+    cli::cli_abort(
+      c(
+        "Terms must not be duplicated on the left- and right-hand side of the
+        {.arg formula}.",
+        "i" = "The following duplicated term{?s} {?was/were} found:
+              {.val {check$duplicates}}"
+      )
     )
   }
 
